@@ -23,10 +23,11 @@
 #include "config.h"
 
 #include "gkr-daemon.h"
+#include "gkr-daemon-util.h"
+
+#include "common/gkr-location.h"
 
 #include "egg/egg-buffer.h"
-#include "common/gkr-daemon-util.h"
-#include "common/gkr-location.h"
 #include "egg/egg-secure-memory.h"
 
 #include "keyrings/gkr-keyring.h"
@@ -304,41 +305,49 @@ request_keyring_access (GkrKeyringRequest *req, GkrKeyring *keyring)
 	
 	if (app->display_name && app->pathname) {
 		if (is_default) {
+			/* TRANSLATORS: The default keyring is locked */
 			message = g_markup_printf_escaped (_("The application '%s' (%s) wants access to "
 						           "the default keyring, but it is locked"),
 						           app->display_name, app->pathname);
 		} else {
+			/* TRANSLATORS: The keyring '%s' is locked */
 			message = g_markup_printf_escaped (_("The application '%s' (%s) wants access to "
 						           "the keyring '%s', but it is locked"),
 						           app->display_name, app->pathname, keyring_name);
 		}
 	} else if (app->display_name) {
 		if (is_default) {
+			/* TRANSLATORS: The default keyring is locked */
 			message = g_markup_printf_escaped (_("The application '%s' wants access to the "
 						           "default keyring, but it is locked"),
 						           app->display_name);
 		} else {
+			/* TRANSLATORS: The keyring '%s' is locked */
 			message = g_markup_printf_escaped (_("The application '%s' wants access to the "
 						           "keyring '%s', but it is locked"),
 						           app->display_name, keyring_name);
 		} 
 	} else if (app->pathname) {
 		if (is_default) {
+			/* TRANSLATORS: The default keyring is locked */
 			message = g_markup_printf_escaped (_("The application '%s' wants access to the "
 						           "default keyring, but it is locked"),
 						           app->pathname);
 		}
 		else {
+			/* TRANSLATORS: The keyring '%s' is locked */
 			message = g_markup_printf_escaped (_("The application '%s' wants access to the "
 						           "keyring '%s', but it is locked"),
 						           app->pathname, keyring_name);
 		}
 	} else { 
 		if (is_default) {
+			/* TRANSLATORS: The default keyring is locked */
 			message = g_markup_printf_escaped (_("An unknown application wants access to the "
 						           "default keyring, but it is locked"));
 		}
 		else {
+			/* TRANSLATORS: The keyring '%s' is locked */
 			message = g_markup_printf_escaped (_("An unknown application wants access to the "
 						           "keyring '%s', but it is locked"),
 						           keyring_name);
@@ -400,40 +409,48 @@ request_new_keyring_password (GkrKeyringRequest *req, const char *keyring_name,
 
 	if (app->display_name && app->pathname) {
 		if (!is_default) {
+			/* TRANSLATORS: The password is for the new keyring */
 			message = g_markup_printf_escaped (_("The application '%s' (%s) wants to create a new keyring called '%s'. "
 						           "You have to choose the password you want to use for it."),
 						           app->display_name, app->pathname, keyring_name);
 		} else {
+			/* TRANSLATORS: The password is for the new keyring */
 			message = g_markup_printf_escaped (_("The application '%s' (%s) wants to create a new default keyring. "
 						           "You have to choose the password you want to use for it."),
 						           app->display_name, app->pathname);
 		} 
 	} else if (app->display_name) {
 		if (!is_default) {
+			/* TRANSLATORS: The password is for the new keyring */
 			message = g_markup_printf_escaped (_("The application '%s' wants to create a new keyring called '%s'. "
 						           "You have to choose the password you want to use for it."),
 						           app->display_name, keyring_name);
 		} else {
+			/* TRANSLATORS: The password is for the new keyring */
 			message = g_markup_printf_escaped (_("The application '%s' wants to create a new default keyring. "
 						           "You have to choose the password you want to use for it."),
 						           app->display_name);
 		} 
 	} else if (app->pathname) {
 		if (!is_default) {
+			/* TRANSLATORS: The password is for the new keyring */
 			message = g_markup_printf_escaped (_("The application '%s' wants to create a new keyring called '%s'. "
 						           "You have to choose the password you want to use for it."),
 						           app->pathname, keyring_name);
 		} else {
+			/* TRANSLATORS: The password is for the new keyring */
 			message = g_markup_printf_escaped (_("The application '%s' wants to create a new default keyring. "
 						           "You have to choose the password you want to use for it."),
 						           app->pathname);
 		} 
 	} else {
 		if (!is_default) {
+			/* TRANSLATORS: The password is for the new keyring */
 			message = g_markup_printf_escaped (_("An unknown application wants to create a new keyring called '%s'. "
 						           "You have to choose the password you want to use for it."),
 						           keyring_name);
 		} else {
+			/* TRANSLATORS: The password is for the new keyring */
 			message = g_markup_printf_escaped (_("An unknown application wants to create a new default keyring. "
 						           "You have to choose the password you want to use for it."));
 		} 
@@ -1586,6 +1603,8 @@ find_in_each_keyring (GkrKeyring* keyring, gpointer data)
 	GkrKeyringItem *item;
 	GList *ilist;
 	
+	g_object_ref (keyring);
+	
 	for (ilist = keyring->items; ilist != NULL; ilist = ilist->next) {
 		item = ilist->data;
 		if (!gkr_keyring_item_match (item, ctx->type, keyring->locked ? ctx->hashed : ctx->attributes, FALSE))
@@ -1595,7 +1614,7 @@ find_in_each_keyring (GkrKeyring* keyring, gpointer data)
 			
 		if (keyring->locked) {
 			if (!request_keyring_access (ctx->req, keyring))
-				return TRUE;
+				break;
 		}
 
 		if (request_item_access (ctx->req, item, GNOME_KEYRING_ACCESS_READ, TRUE)) {
@@ -1603,7 +1622,9 @@ find_in_each_keyring (GkrKeyring* keyring, gpointer data)
 			ctx->items = g_list_prepend (ctx->items, item);
 		}
 	}
-	
+
+	g_object_unref (keyring);
+
 	return TRUE;
 }
 
