@@ -19,4 +19,19 @@
 #define WAIT_UNTIL(cond) \
 	while(!cond) g_main_context_iteration (NULL, TRUE);
 
+/* 
+ * Some dumb crypto mechanisms for simple testing.
+ * 
+ * CKM_CAPITALIZE (encrypt/decrypt)
+ *     capitalizes to encrypt
+ *     lowercase to decrypt 
+ *
+ * CKM_PREFIX (sign/verify)
+ *     sign prefixes data with key label
+ *     verify unprefixes data with key label. 
+ */
+
+#define CKM_CAPITALIZE    (CKM_VENDOR_DEFINED | 1)
+#define CKM_PREFIX        (CKM_VENDOR_DEFINED | 2)
+
 #endif /*TESTGP11HELPERS_H_*/
